@@ -23,6 +23,7 @@ from snaptrade_client.model.account_order_record import AccountOrderRecord
 from snaptrade_client.model.account_order_record_status import AccountOrderRecordStatus
 from snaptrade_client.model.account_simple import AccountSimple
 from snaptrade_client.model.account_sync_status import AccountSyncStatus
+from snaptrade_client.model.account_universal_activity import AccountUniversalActivity
 from snaptrade_client.model.action import Action
 from snaptrade_client.model.action_strict import ActionStrict
 from snaptrade_client.model.action_strict_with_options import ActionStrictWithOptions
@@ -40,7 +41,15 @@ from snaptrade_client.model.brokerage_exchanges import BrokerageExchanges
 from snaptrade_client.model.brokerage_order_id import BrokerageOrderID
 from snaptrade_client.model.brokerage_symbol_id import BrokerageSymbolID
 from snaptrade_client.model.brokerage_type import BrokerageType
+from snaptrade_client.model.child_brokerage_order_ids import ChildBrokerageOrderIDs
+from snaptrade_client.model.child_brokerage_order_ids_nullable import ChildBrokerageOrderIDsNullable
 from snaptrade_client.model.client_id import ClientID
+from snaptrade_client.model.cryptocurrency_base_symbol import CryptocurrencyBaseSymbol
+from snaptrade_client.model.cryptocurrency_pair import CryptocurrencyPair
+from snaptrade_client.model.cryptocurrency_pair_quote import CryptocurrencyPairQuote
+from snaptrade_client.model.cryptocurrency_pair_symbol import CryptocurrencyPairSymbol
+from snaptrade_client.model.cryptocurrency_quote_symbol import CryptocurrencyQuoteSymbol
+from snaptrade_client.model.cryptocurrency_symbol import CryptocurrencySymbol
 from snaptrade_client.model.currency import Currency
 from snaptrade_client.model.currency_id import CurrencyID
 from snaptrade_client.model.currency_nullable import CurrencyNullable
@@ -62,8 +71,10 @@ from snaptrade_client.model.manual_trade import ManualTrade
 from snaptrade_client.model.manual_trade_and_impact import ManualTradeAndImpact
 from snaptrade_client.model.manual_trade_balance import ManualTradeBalance
 from snaptrade_client.model.manual_trade_form import ManualTradeForm
+from snaptrade_client.model.manual_trade_form_bracket import ManualTradeFormBracket
 from snaptrade_client.model.manual_trade_form_with_options import ManualTradeFormWithOptions
 from snaptrade_client.model.manual_trade_impact import ManualTradeImpact
+from snaptrade_client.model.manual_trade_replace_form import ManualTradeReplaceForm
 from snaptrade_client.model.manual_trade_symbol import ManualTradeSymbol
 from snaptrade_client.model.model400_failed_request_response import Model400FailedRequestResponse
 from snaptrade_client.model.model401_failed_request_response import Model401FailedRequestResponse
@@ -95,6 +106,9 @@ from snaptrade_client.model.options_symbol import OptionsSymbol
 from snaptrade_client.model.options_symbol_nullable import OptionsSymbolNullable
 from snaptrade_client.model.order_type import OrderType
 from snaptrade_client.model.order_type_strict import OrderTypeStrict
+from snaptrade_client.model.order_updated_response import OrderUpdatedResponse
+from snaptrade_client.model.paginated_universal_activity import PaginatedUniversalActivity
+from snaptrade_client.model.pagination_details import PaginationDetails
 from snaptrade_client.model.partner_data import PartnerData
 from snaptrade_client.model.past_value import PastValue
 from snaptrade_client.model.performance_custom import PerformanceCustom
@@ -111,6 +125,8 @@ from snaptrade_client.model.reporting_frequency import ReportingFrequency
 from snaptrade_client.model.security_type import SecurityType
 from snaptrade_client.model.security_type_id import SecurityTypeID
 from snaptrade_client.model.session_event import SessionEvent
+from snaptrade_client.model.simple_order_preview import SimpleOrderPreview
+from snaptrade_client.model.simple_order_preview_estimated_fee import SimpleOrderPreviewEstimatedFee
 from snaptrade_client.model.snap_trade_holdings_account import SnapTradeHoldingsAccount
 from snaptrade_client.model.snap_trade_holdings_account_meta import SnapTradeHoldingsAccountMeta
 from snaptrade_client.model.snap_trade_holdings_total_value import SnapTradeHoldingsTotalValue
@@ -118,7 +134,6 @@ from snaptrade_client.model.snap_trade_login_user_request_body import SnapTradeL
 from snaptrade_client.model.snap_trade_register_user_request_body import SnapTradeRegisterUserRequestBody
 from snaptrade_client.model.status import Status
 from snaptrade_client.model.stop_loss import StopLoss
-from snaptrade_client.model.stop_loss_nullable import StopLossNullable
 from snaptrade_client.model.strategy_order_record import StrategyOrderRecord
 from snaptrade_client.model.strategy_quotes import StrategyQuotes
 from snaptrade_client.model.strategy_quotes_greek import StrategyQuotesGreek
@@ -130,11 +145,11 @@ from snaptrade_client.model.symbols_quotes import SymbolsQuotes
 from snaptrade_client.model.sync_status_date import SyncStatusDate
 from snaptrade_client.model.sync_status_date_nullable import SyncStatusDateNullable
 from snaptrade_client.model.take_profit import TakeProfit
-from snaptrade_client.model.take_profit_nullable import TakeProfitNullable
 from snaptrade_client.model.time import Time
 from snaptrade_client.model.time_in_force import TimeInForce
 from snaptrade_client.model.time_in_force_strict import TimeInForceStrict
 from snaptrade_client.model.trade_id import TradeID
+from snaptrade_client.model.trading_instrument import TradingInstrument
 from snaptrade_client.model.transactions_status import TransactionsStatus
 from snaptrade_client.model.us_exchange import USExchange
 from snaptrade_client.model.underlying_symbol import UnderlyingSymbol
