@@ -471,6 +471,22 @@ operation_parameter_map = {
             },
         ]
     },
+    '/accounts/{accountId}/trading/simple/{brokerageOrderId}/cancel-POST': {
+        'parameters': [
+            {
+                'name': 'userId'
+            },
+            {
+                'name': 'userSecret'
+            },
+            {
+                'name': 'accountId'
+            },
+            {
+                'name': 'brokerageOrderId'
+            },
+        ]
+    },
     '/accounts/{accountId}/orders/cancel-POST': {
         'parameters': [
             {
@@ -487,6 +503,22 @@ operation_parameter_map = {
             },
         ]
     },
+    '/accounts/{accountId}/trading/instruments/cryptocurrencyPairs/{instrumentSymbol}/quote-GET': {
+        'parameters': [
+            {
+                'name': 'userId'
+            },
+            {
+                'name': 'userSecret'
+            },
+            {
+                'name': 'accountId'
+            },
+            {
+                'name': 'instrumentSymbol'
+            },
+        ]
+    },
     '/trade/impact-POST': {
         'parameters': [
             {
@@ -543,6 +575,49 @@ operation_parameter_map = {
             },
         ]
     },
+    '/accounts/{accountId}/trading/bracket-POST': {
+        'parameters': [
+            {
+                'name': 'action'
+            },
+            {
+                'name': 'instrument'
+            },
+            {
+                'name': 'order_type'
+            },
+            {
+                'name': 'time_in_force'
+            },
+            {
+                'name': 'stop_loss'
+            },
+            {
+                'name': 'take_profit'
+            },
+            {
+                'name': 'accountId'
+            },
+            {
+                'name': 'userId'
+            },
+            {
+                'name': 'userSecret'
+            },
+            {
+                'name': 'symbol'
+            },
+            {
+                'name': 'price'
+            },
+            {
+                'name': 'stop'
+            },
+            {
+                'name': 'units'
+            },
+        ]
+    },
     '/trade/place-POST': {
         'parameters': [
             {
@@ -581,15 +656,6 @@ operation_parameter_map = {
             {
                 'name': 'notional_value'
             },
-            {
-                'name': 'order_class'
-            },
-            {
-                'name': 'stop_loss'
-            },
-            {
-                'name': 'take_profit'
-            },
         ]
     },
     '/trade/{tradeId}-POST': {
@@ -608,6 +674,139 @@ operation_parameter_map = {
             },
         ]
     },
+    '/accounts/{accountId}/trading/simple-POST': {
+        'parameters': [
+            {
+                'name': 'instrument'
+            },
+            {
+                'name': 'side'
+            },
+            {
+                'name': 'type'
+            },
+            {
+                'name': 'time_in_force'
+            },
+            {
+                'name': 'amount'
+            },
+            {
+                'name': 'userId'
+            },
+            {
+                'name': 'userSecret'
+            },
+            {
+                'name': 'accountId'
+            },
+            {
+                'name': 'limit_price'
+            },
+            {
+                'name': 'stop_price'
+            },
+            {
+                'name': 'post_only'
+            },
+            {
+                'name': 'expiration_date'
+            },
+        ]
+    },
+    '/accounts/{accountId}/trading/simple/preview-POST': {
+        'parameters': [
+            {
+                'name': 'instrument'
+            },
+            {
+                'name': 'side'
+            },
+            {
+                'name': 'type'
+            },
+            {
+                'name': 'time_in_force'
+            },
+            {
+                'name': 'amount'
+            },
+            {
+                'name': 'userId'
+            },
+            {
+                'name': 'userSecret'
+            },
+            {
+                'name': 'accountId'
+            },
+            {
+                'name': 'limit_price'
+            },
+            {
+                'name': 'stop_price'
+            },
+            {
+                'name': 'post_only'
+            },
+            {
+                'name': 'expiration_date'
+            },
+        ]
+    },
+    '/accounts/{accountId}/trading/simple/{brokerageOrderId}/replace-PATCH': {
+        'parameters': [
+            {
+                'name': 'action'
+            },
+            {
+                'name': 'order_type'
+            },
+            {
+                'name': 'time_in_force'
+            },
+            {
+                'name': 'accountId'
+            },
+            {
+                'name': 'brokerageOrderId'
+            },
+            {
+                'name': 'userId'
+            },
+            {
+                'name': 'userSecret'
+            },
+            {
+                'name': 'price'
+            },
+            {
+                'name': 'stop'
+            },
+            {
+                'name': 'units'
+            },
+        ]
+    },
+    '/accounts/{accountId}/trading/instruments/cryptocurrencyPairs-GET': {
+        'parameters': [
+            {
+                'name': 'userId'
+            },
+            {
+                'name': 'userSecret'
+            },
+            {
+                'name': 'accountId'
+            },
+            {
+                'name': 'base'
+            },
+            {
+                'name': 'quote'
+            },
+        ]
+    },
     '/activities-GET': {
         'parameters': [
             {
